# -*- coding: utf-8 -*-
"""
Created on Thu Jul 22 11:56:22 2021

@author: Michael Nauge, Université de Poitiers


Les codes de communication avec Nakala sont dispersés dans différents
fichiers mais l'idée est que celà reste transparent 
pour l'utilisateur de la librairie
"""

from NklTarget import *
from nklPullCorpus import *